@@ -11,7 +11,6 @@
 #'                       \item \strong{\code{regret_inputs}}: Named list of regret functions. This should contain one list per attribute, where these lists themselves contain two vectors, namely a vector of attributes (at the alternative level) and parameters (either generic or attribute specific). Zeros can be used for omitted attributes for some alternatives. The order for each attribute needs to be the same as the order in \code{alternatives.}.
 #'                       \item \strong{\code{regret_scale}}: Named list of regret scales. This should have the same length as 'rrm_settings$regret_inputs' or be a single entry in the case of a generic scale parameter across regret attributes.
 #'                       \item \strong{\code{choiceset_scaling}}: Vector. One entry per row in the database, often set to 2 divided by the number of available alternatives.
-#'                       \item \strong{\code{utilities}}: Named list of deterministic utilities. Utilities of the alternatives. Names of elements must match those in \code{alternatives.}
 #'                       \item \strong{\code{rows}}: Boolean vector. Consideration of which rows to include. Length equal to the number of observations (nObs), with entries equal to TRUE for rows to include, and FALSE for rows to exclude. Default is \code{"all"}, equivalent to \code{rep(TRUE, nObs)}.
 #'                       \item \strong{\code{componentName}}: Character. Name given to model component. If not provided by the user, Apollo will set the name automatically according to the element in \code{P} to which the function output is directed.
 #'                     }
@@ -156,9 +155,9 @@ apollo_rrm <- function(rrm_settings, functionality){
     isText <- isText && is.list(rrm_settings$regret_inputs)
     for(le in rrm_settings$regret_inputs){
       isText <- isText && is.list(le) && length(le)==2 && !is.null(names(le))
-      isText <- isText && names(le) %in% c("x", "b")
-      isText <- isText && sapply(le[["x"]], is.character)
-      isText <- isText && sapply(le[["b"]], is.character)
+      isText <- isText && all(names(le) %in% c("x", "b"))
+      isText <- isText && all(sapply(le[["x"]], is.character))
+      isText <- isText && all(sapply(le[["b"]], is.character))
     }
     isText <- isText && (is.null(rrm_settings$regret_inputs) || 
                            (is.list(rrm_settings$regret_scale) && all(sapply(rrm_settings$regret_scale, is.character))))
